import React from 'react';
import * as PropTypes from 'prop-types';
import TextLabel from '../TextLabel/TextLabel';
import TextField from '../TextField/TextField';
import Switch from '../Toggle/Toggle';
import getStyles from './AdvancedSettingsOptions.styles';

/**
 * Allows to configure advanced settings related to the app.
 */
const AdvancedSettingsOptions = (props) => {
    const {
        contextStyles,
        errors,
        serverURLLabelText,
        useServerToggleText,
        useServer,
        serverURL,
        onUseServerChange,
        onServerURLChange,
    } = props;

    const styles = getStyles(contextStyles);

    return (
        <>
            <div style={ styles.serverContainer }>
                <TextLabel>
                    { serverURLLabelText }
                </TextLabel>
                <TextField
                    disabled={ !useServer }
                    onChange={ onServerURLChange }
                    value={ serverURL } />
                { errors && errors['server'] &&
                    <TextLabel
                        error
                        contextStyles={ {
                            container: contextStyles.error,
                        } }>
                        { errors['server'] }
                    </TextLabel>
                }
            </div>
            <div style={ styles.useServerContainer }>
                <Switch
                    checked={ useServer }
                    onChange={ onUseServerChange } />
                <TextLabel>
                    { useServerToggleText }
                </TextLabel>
            </div>
        </>
    );
};

AdvancedSettingsOptions.propTypes = {
    /** Styles for the component */
    contextStyles: PropTypes.shape({
        container: PropTypes.object,
        serverContainer: PropTypes.object,
        useServerContainer: PropTypes.object,
        error: PropTypes.object,
    }),

    /** Various errors on the fields */
    errors: PropTypes.shape({
        server: PropTypes.string,
    }),

    /** The server URL */
    serverURL: PropTypes.string.isRequired,

    /** The server URL label text.*/
    serverURLLabelText: PropTypes.string,

    /** The 'Use Server' Toggle label text. */
    useServerToggleText: PropTypes.string,

    /** The value of the Toggle 'Use Server' */
    useServer: PropTypes.bool.isRequired,

    /** Called when user toggles 'Use Server' */
    onUseServerChange: PropTypes.func.isRequired,

    /** Called when user changes the value of the SERVER URL in the text field. */
    onServerURLChange: PropTypes.func.isRequired,
};

AdvancedSettingsOptions.defaultProps = {
    contextStyles: {},
    serverURLLabelText: 'Server URL',
    useServerToggleText: 'Use Server',
};

export default AdvancedSettingsOptions;