import React, { Component } from 'react';
import { ScrollView, Text, TextInput, View } from 'react-native';
import * as PropTypes from 'prop-types';

import TextLabel from '../TextLabel/TextLabel';

// import CvButton from '../buttons/CvButton';
import Button, { VARIANT } from '../Button/Button';

// import CvDropDown from '../base/CvDropDown';
import DropDown from '../DropDown/DropDown';

import RadioButton from '../base/RadioButton';


// import CvMenuItem from '../base/CvMenuItem';
import MenuItem from '../MenuItem/MenuItem';

import getStyles from './SearchSortForm.styles';

const PLACEHOLDER_INDEX = -1;
const NO_VISIBLE_INDEX = -99;
const NOT_SELECTED_LABEL = lang.searchSort.sortNotSelected;
const NOT_SELECTED = 'NOT_SELECTED';
const PLACEHOLDER_TERM = {
    name: NOT_SELECTED,
    label: NOT_SELECTED_LABEL,
    isAscending: true,
};

class SearchSortForm extends Component {
    static defaultProps = {
        contextStyles: {},
        title: 'Search/Sort',
        instructions: 'Enter a term to be searched for and/or sorted on throughout the list data.',
        filterTitle: 'Filter criteria (optional)',
        sortTitle: 'Sort criteria (optional)',
        sortNotSelectedText: '(not selected)',
        clearButtonText: 'Clear',
        cancelButtonText: 'Cancel',
        submitButtonText: 'Search/Sort',
    };

    static propTypes = {
        /** Text Labels */
        title: PropTypes.string,
        instructions: PropTypes.string,
        filterTitle: PropTypes.string,
        sortTitle: PropTypes.string,
        sortNotSelectedText: PropTypes.string,
        clearButtonText: PropTypes.string,
        cancelButtonText: PropTypes.string,
        submitButtonText: PropTypes.string,

        /** Styles for this component */
        contextStyles: PropTypes.shape({
            /** Styles for the main wrapping container */
            container: PropTypes.object,
            titleContainer: PropTypes.object,
            titleText: PropTypes.object,
            instructionsContainer: PropTypes.object,
            instructionsText: PropTypes.object,
            scrollView: PropTypes.object,
            filterContainer: PropTypes.object,
            filterTextLabel: PropTypes.object,
            filterTextInput: PropTypes.object,
            sortContainer: PropTypes.object,
            sortTextLabel: PropTypes.object,
            sortControlContainer: PropTypes.object,
            sortControlRow1: PropTypes.object,
            sortControlRow2: PropTypes.object,
            removeButton: PropTypes.object,
            sortDivider: PropTypes.object,
            buttonContainer: PropTypes.object,
        }),

        // searchTerm: PropTypes.string,
        // sortTerms: PropTypes.arrayOf(PropTypes.shape({
        //     name: PropTypes.string.isRequired,
        //     isAscending: PropTypes.bool.isRequired,
        // })),
        // sortableValues: PropTypes.arrayOf(PropTypes.shape({
        //     name: PropTypes.string,
        //     label: PropTypes.string,
        //     isAscending: PropTypes.bool,
        // })).isRequired,

        /** Called on click of the clear button */
        onClear: PropTypes.func.isRequired,

        /** Called on click of the cancel button */
        onCancel: PropTypes.func.isRequired,

        /** Called on click of the submit button */
        onSubmit: PropTypes.func.isRequired,

        // onSearchTermChange: PropTypes.func.isRequired,
        // onSortTermsChange: PropTypes.func.isRequired,
    };

    // constructor(props) {
    //     super(props);
    //     this.state = {
    //         dropDownMenuVisibleIndex: NO_VISIBLE_INDEX,
    //     };
    // }

    render() {
        const {
            // searchTerm,
            // sortNotSelectedText,
            contextStyles,
            title,
            instructions,
            filterTitle,
            sortTitle,
            clearButtonText,
            cancelButtonText,
            submitButtonText,
        } = this.props;

        const styles = getStyles(contextStyles);

        // Generate container props
        const containerProps = {
            style: styles.container,
        };

        // Generate title props
        const titleProps = {
            contextStyles: {
                container: styles.titleContainer,
                text: styles.titleText,
            },
        };

        // Generate instructions props
        const instructionsProps = {
            contextStyles: {
                container: styles.instructionsContainer,
                text: styles.instructionsText,
            },
        };

        return (
            <div { ...containerProps }>
                <TextLabel { ...titleProps }>
                    { title }
                </TextLabel>
                <TextLabel { ...instructionsProps }>
                    { instructions }
                </TextLabel>

                <ScrollView style={ styles.scrollView }>
                    <View style={ styles.filterContainer }>
                        <Text style={ styles.filterTextLabel }>
                            { filterTitle }
                        </Text>
                        <TextInput
                            onEndEditing={ (e) => { this.handleSearchTermEndEditing(e.nativeEvent.text); } }
                            defaultValue={ searchTerm }
                            style={ styles.filterTextInput } />
                    </View>
                    <View style={ styles.sortContainer }>
                        <Text style={ styles.sortTextLabel }>
                            { sortTitle }
                        </Text>

                        { /* { this.renderSortControls() } */ }
                        <div>SORT CONTROLS HERE</div>

                    </View>
                </ScrollView>

                <div style={ styles.buttonContainer }>
                    <Button
                        variant={ VARIANT.OUTLINED }
                        text={ clearButtonText }
                        onClick={ this.handleClear } />
                    <Button
                        contextStyles={ { container: { marginLeft: '2rem' } } }
                        variant={ VARIANT.OUTLINED }
                        text={ cancelButtonText }
                        onClick={ this.handleCancel } />
                    <Button
                        contextStyles={ { container: { marginLeft: '2rem' } } }
                        text={ submitButtonText }
                        onClick={ this.handleSubmit } />
                </div>
            </div>
        );
    }

    // renderSortControls = () => {
    //     const result = [];
    //     const { sortTerms } = this.props;
    //     // For each sort field in the state, render a control.
    //     sortTerms.forEach((e, i) => {
    //         result.push(this.renderSortControl(i));
    //         result.push(this.renderSortDivider(i));
    //     });
    //
    //     // Then render one more control so the user can add an additional sort to the compound sort.
    //     result.push(this.renderSortControl(PLACEHOLDER_INDEX));
    //     return result;
    // };

    // renderSortDivider = (index) => {
    //     const { contextStyles } = this.props;
    //     const styles = getSearchSortFormStyles(contextStyles);
    //     return (
    //         <View
    //             style={ styles.sortDivider }
    //             key={ `separator-${index}` } />
    //     );
    // };

    // renderSortControl = (index) => {
    //     // The sort control consists of:
    //     // 1) A drop down to select the field to sort by
    //     // 2) An optional control to remove this field from the sort entirely
    //     // 3) A control to choose ascending vs descending
    //     // NOTE 1: The last entry has an index of -1, and does not have the remove tool.
    //     // NOTE 2: The last entry has a special value in the drop down of (not selected).
    //     const { contextStyles, sortTerms, sortableValues } = this.props;
    //     const styles = getSearchSortFormStyles(contextStyles);
    //     const isPlaceholder = index === PLACEHOLDER_INDEX;
    //     const selectedSortTerm = isPlaceholder ? PLACEHOLDER_TERM : sortTerms[index];
    //     const { dropDownMenuVisibleIndex } = this.state;
    //     const available = sortableValues.slice();
    //     if (isPlaceholder) {
    //         // Add the (not selected) as the first entry.
    //         available.unshift(selectedSortTerm);
    //
    //         // Any sort fields referenced already should be removed from the list.
    //         // Makes no sense to sort by country, state, state
    //         let i = 0;
    //         while (i < sortTerms.length) {
    //             // eslint-disable-next-line no-loop-func
    //             const i2 = available.findIndex(f => f.name === sortTerms[i].name);
    //             available.splice(i2, 1);
    //             i += 1;
    //         }
    //     }
    //     return (
    //         <View
    //             style={ styles.sortControlContainer }
    //             key={ index }>
    //             <View style={ styles.sortControlRow1 }>
    //                 { isPlaceholder ? null
    //                     : (
    //                         <CvButton
    //                             contextStyles={ styles.removeButton }
    //                             iconCls="minus-circle"
    //                             onPress={ () => this.handleRemove(index) } />
    //                     )
    //                 }
    //                 <CvDropDown
    //                     selectedItem={ selectedSortTerm }
    //                     items={ available }
    //                     onRenderItem={ (item) => { return this.handleRenderItem(item, index); } }
    //                     onRenderSelectedItem={ item => { return (<Text>{item.label}</Text>); } }
    //                     onPressDropDown={ () => { this.handleOpenDropDown(index); } }
    //                     onPressOverlay={ this.handlePressOverlay }
    //                     isMenuVisible={ dropDownMenuVisibleIndex === index } />
    //             </View>
    //             {isPlaceholder ? null
    //                 : (
    //                     <View style={ styles.sortControlRow2 }>
    //                         <RadioButton
    //                             contextStyles={ { text: { marginRight: 15 } } }
    //                             text="Ascending"
    //                             selected={ selectedSortTerm.isAscending }
    //                             onPress={ () => this.selectAscending(index) } />
    //                         <RadioButton
    //                             text="Descending"
    //                             selected={ !selectedSortTerm.isAscending }
    //                             onPress={ () => this.selectDescending(index) } />
    //                     </View>
    //                 )
    //             }
    //         </View>
    //     );
    // };

    handleClear = () => {
        const { onClear } = this.props;
        onClear();
    };

    handleCancel = () => {
        const { onCancel } = this.props;
        onCancel();
    };

    handleSubmit = () => {
        const { onSubmit } = this.props;
        onSubmit();
    };

    // handleOpenDropDown= (index) => {
    //     // Set the menu to be visible.
    //     this.setState({ dropDownMenuVisibleIndex: index });
    // };

    // handlePressOverlay = () => {
    //     this.setState({
    //         dropDownMenuVisibleIndex: NO_VISIBLE_INDEX,
    //     });
    // };

    // handleRemove = (index) => {
    //     const { onSortTermsChange } = this.props;
    //     const sortTerms = this.getSortTermsCopy();
    //     sortTerms.splice(index, 1);
    //     onSortTermsChange(sortTerms);
    // };

    // handleRenderItem = (item, index) => {
    //     const { sortTerms } = this.props;
    //     const sortTerm = this.getSortTerm(sortTerms, index);
    //     return (
    //         <CvMenuItem
    //             isSelected={ sortTerm.name === item.name }
    //             text={ item.label }
    //             onPress={ () => { this.handleSelectFromDropDown(item, index); } }
    //             key={ item.name } />
    //     );
    // };

    // handleSearchTermEndEditing = (text) => {
    //     const { onSearchTermChange } = this.props;
    //     onSearchTermChange(text);
    // };

    // handleSelectFromDropDown = (item, index) => {
    //     if (item === NOT_SELECTED) {
    //         this.setState({
    //             dropDownMenuVisibleIndex: NO_VISIBLE_INDEX,
    //         });
    //     } else {
    //         const sortTerms = this.getSortTermsCopy();
    //         if (index === PLACEHOLDER_INDEX) {
    //             // Add a new sort term into the mix.
    //             sortTerms.push(this.copySortTerm(item));
    //         } else {
    //             sortTerms[index] = item;
    //         }
    //         this.setState({
    //             dropDownMenuVisibleIndex: NO_VISIBLE_INDEX,
    //         });
    //         const { onSortTermsChange } = this.props;
    //         onSortTermsChange(sortTerms);
    //     }
    // };


    // getSortTermsCopy = () => {
    //     const { sortTerms } = this.props;
    //     return sortTerms.map(m => {
    //         const { name, isAscending } = m;
    //         return { name, isAscending };
    //     });
    // };

    // getSortTerm = (sortTerms, index) => {
    //     return (index === PLACEHOLDER_INDEX) ? PLACEHOLDER_TERM : sortTerms[index];
    // };

    // getSortTermCopy = (sortTerms, index) => {
    //     return (index === PLACEHOLDER_INDEX) ? PLACEHOLDER_TERM : this.copySortTerm(sortTerms[index]);
    // };

    // copySortTerm = (sortTerm) => {
    //     const { name, label, isAscending } = sortTerm;
    //     return { name, label, isAscending };
    // };

    // selectAscending = (index) => {
    //     if (index >= 0) {
    //         const { onSortTermsChange } = this.props;
    //         const sortTerms = this.getSortTermsCopy();
    //         const sortTerm = this.getSortTermCopy(sortTerms, index);
    //         sortTerm.isAscending = true;
    //         sortTerms[index] = sortTerm;
    //         onSortTermsChange(sortTerms);
    //     }
    // };

    // selectDescending = (index) => {
    //     if (index >= 0) {
    //         const { onSortTermsChange } = this.props;
    //         const sortTerms = this.getSortTermsCopy();
    //         const sortTerm = this.getSortTermCopy(sortTerms, index);
    //         sortTerm.isAscending = false;
    //         sortTerms[index] = sortTerm;
    //         onSortTermsChange(sortTerms);
    //     }
    // };
}

export default SearchSortForm;
