import React from 'react';
import * as PropTypes from 'prop-types';

import TextLabel from '../TextLabel/TextLabel';
import TextField from '../TextField/TextField';
import Switch from '../Toggle/Toggle';
import Button from '../Button/Button';
import IconButton from '../IconButton/IconButton';
import AdvancedSettingsOptions from '../AdvancedSettingsOptions/AdvancedSettingsOptions';
import getStyles from './SettingsForm.styles';

const SettingsForm = (props) => {
    const {
        contextStyles,
        errors,
        isSaving,
        onCancelPress,
        onSavePress,
        onServerChange,
        onTenantChange,
        onUseOAuthChange,
        onUseServerChange,
        onClickDebugMode,
        server,
        tenant,
        useOAuth,
        useServer,
        showToggleServer,
    } = props;

    const styles = getStyles(contextStyles);

    const disableButtons = isSaving || !tenant || !tenant.trim() || (useServer && !server);

    return (
        <div style={ styles.container }>
            <h2 style={ styles.heading }>Settings</h2>

            <div style={ styles.tenantContainer }>
                <TextLabel>Tenant ID</TextLabel>
                <TextField
                    onChange={ onTenantChange }
                    value={ tenant }
                    autoFocus />
                { errors && errors['tenant'] &&
                    <TextLabel
                        error
                        contextStyles={ {
                            container: styles.error,
                        } }>
                        { errors['tenant'] }
                    </TextLabel>
                }
            </div>

            { showToggleServer &&
                <AdvancedSettingsOptions
                    useServer={ useServer }
                    contextStyles={ styles }
                    serverURL={ server }
                    errors={ errors }
                    onServerURLChange={ onServerChange }
                    onUseServerChange={ onUseServerChange } />
            }

            <div style={ styles.useOAuthContainer }>
                <Switch
                    checked={ useOAuth }
                    onChange={ onUseOAuthChange } />
                <TextLabel>Use OAuth</TextLabel>
            </div>


            { errors && errors['main'] &&
                <TextLabel
                    error
                    contextStyles={ {
                        container: styles.error,
                    } }>
                    { errors['main'] }
                </TextLabel>
            }
            <div style={ styles.buttonContainer }>
                <Button
                    contextStyles={ {
                        container: styles.button,
                        text: styles.buttonText,
                    } }
                    onClick={ onSavePress }
                    disabled={ disableButtons }
                    text="Save" />
                <Button
                    contextStyles={ {
                        container: styles.button,
                        text: styles.buttonText,
                    } }
                    onClick={ onCancelPress }
                    disabled={ disableButtons }
                    text="Cancel"
                    variant="outlined" />

                { /* 'Help' icon is assigned to the IconButton. The icon is hidden in the UI using css. Only the click action can be perfromed */ }
                <IconButton
                    contextStyles={ {
                        icon: styles.debugIconButton,
                        container: styles.iconButtonContainer,
                    } }
                    iconName="help"
                    onClick={ onClickDebugMode } />
            </div>
        </div>
    );
};

SettingsForm.propTypes = {
    contextStyles: PropTypes.shape({
        container: PropTypes.object,
        heading: PropTypes.object,
    }),
    errors: PropTypes.shape({
        main: PropTypes.string,
        tenant: PropTypes.string,
        server: PropTypes.string,
    }),
    isSaving: PropTypes.bool,
    showToggleServer: PropTypes.bool,
    onCancelPress: PropTypes.func.isRequired,
    onSavePress: PropTypes.func.isRequired,
    onServerChange: PropTypes.func.isRequired,
    onTenantChange: PropTypes.func.isRequired,
    onUseOAuthChange: PropTypes.func.isRequired,
    onUseServerChange: PropTypes.func.isRequired,
    onClickDebugMode: PropTypes.func.isRequired,
    server: PropTypes.string.isRequired,
    tenant: PropTypes.string.isRequired,
    useOAuth: PropTypes.bool.isRequired,
    useServer: PropTypes.bool.isRequired,
};

SettingsForm.defaultProps = {
    contextStyles: {},
};

export default SettingsForm;
