/**
 * Core component style object that contains style objects
 * for all the styles for inner elements.
 */
const coreStyles = {
    container: {
        display: 'flex',
        flexDirection: 'column',
        padding: '0 2rem 2rem 2rem',
        border: '1px solid #ccc',
        borderRadius: '0.5rem',
        boxShadow: '0.25rem 0.25rem 0.5rem 0 rgba(0, 0, 0, 0.5)',
        width: '40%',
        minWidth: '500px',
    },

    heading: {},

    label: {},

    input: {
        width: '100%',
    },

    toggle: {},

    button: {},

    buttonText: {},

    error: {
        marginTop: '1rem',
    },

    tenantContainer: {
        display: 'flex',
        flexDirection: 'column',
    },

    useOAuthContainer: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center',
        marginTop: '1rem',
    },

    buttonContainer: {
        display: 'flex',
        flexDirection: 'row',
        marginTop: '1rem',
    },

    debugIconButton: {
        visibility: 'hidden',
    },

    iconButtonContainer: {
        marginLeft: 'auto',
    },
};

/**
 * Combine all styles, including context styles,
 * into a single style object for
 * @param {Object} contextStyles
 */
const getStyles = (contextStyles = {}) => {
    return {
        container: {
            ...coreStyles.container,
            ...contextStyles.container,
        },

        heading: {
            ...coreStyles.heading,
            ...contextStyles.heading,
        },

        button: {
            ...coreStyles.button,
            ...contextStyles.button,
        },

        buttonText: {
            ...coreStyles.buttonText,
            ...contextStyles.buttonText,
        },

        error: {
            ...coreStyles.error,
            ...contextStyles.error,
        },

        tenantContainer: {
            ...coreStyles.tenantContainer,
            ...contextStyles.tenantContainer,
        },

        serverContainer: {
            ...coreStyles.serverContainer,
            ...contextStyles.serverContainer,
        },

        useOAuthContainer: {
            ...coreStyles.useOAuthContainer,
            ...contextStyles.useOAuthContainer,
        },

        useServerContainer: {
            ...coreStyles.useServerContainer,
            ...contextStyles.useServerContainer,
        },

        buttonContainer: {
            ...coreStyles.buttonContainer,
            ...contextStyles.buttonContainer,
        },

        debugIconButton: {
            ...coreStyles.debugIconButton,
        },

        iconButtonContainer: {
            ...coreStyles.iconButtonContainer,
        },
    };
};

export default getStyles;
